@@ -19,12 +19,13 @@ bot_statistics = """
 -> Number of extensions loaded: {8}
 """
 
+
 class DebugView(View):
     def __init__(self, ctx: Context):
         super().__init__()
 
         self.ctx = ctx
-        self.bot = ctx.bot
+        self.bot: Bot = ctx.bot
 
     async def interaction_check(self, interaction: MessageInteraction) -> bool:
         self.bot_message = get_bot_message(self.ctx)
@@ -78,9 +79,9 @@ class DebugView(View):
     async def cogs_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
-            -> load 
+            -> load
                 => load cog
-            -> unload 
+            -> unload
                 => unload cog
             -> reload
                 => reload cog/all
@@ -88,9 +89,7 @@ class DebugView(View):
 
         from . import Cogs
 
-        embed = EmbedFactory.static_embed(
-            self.ctx, "Manage cogs", path="cogs"
-        )
+        embed = EmbedFactory.static_embed(self.ctx, "Manage cogs", path="cogs")
 
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed, view=Cogs(self.ctx))
@@ -115,6 +114,9 @@ class DebugView(View):
         await interaction.response.send_message("What id/name?", ephemeral=True)
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         response = await FindSnowflake.find_channel(self.bot, message.content)
         if not response:
             other_response = await FindSnowflake.find_any(self.bot, message.content)
@@ -144,7 +146,9 @@ class DebugView(View):
             )
             return await self.bot_message.edit(embed=embed)
 
-        await interaction.send("Loading messages...this might take a while if the channel contains long messages")
+        await interaction.send(
+            "Loading messages...this might take a while if the channel contains long messages"
+        )
         view = await Channel.create(self.ctx, response)
         await self.bot_message.edit(view=view)
 
@@ -161,13 +165,12 @@ class DebugView(View):
 
         from . import Eval
 
-        embed = EmbedFactory.static_embed(
-            self.ctx, "Evaluate code", path="eval")
+        embed = EmbedFactory.static_embed(self.ctx, "Evaluate code", path="eval")
 
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed, view=Eval(self.ctx))
 
-    @button(label="Github", style=ButtonStyle.green)
+    @button(label="Github", style=ButtonStyle.green, row=1)
     async def github_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
@@ -182,7 +185,7 @@ class DebugView(View):
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed, view=Github(self.ctx))
 
-    @button(label="Invokes", style=ButtonStyle.green)
+    @button(label="Invokes", style=ButtonStyle.green, row=1)
     async def invoke_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
@@ -203,7 +206,7 @@ class DebugView(View):
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed, view=Invokes(self.ctx))
 
-    @button(label="Leave guild", style=ButtonStyle.green)
+    @button(label="Leave guild", style=ButtonStyle.green, row=1)
     async def leave_guild_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
@@ -213,28 +216,35 @@ class DebugView(View):
 
         from . import LeaveGuild
 
-        embed = EmbedFactory.static_embed(
-            self.ctx, "Leave guild", path="leave_guild")
+        embed = EmbedFactory.static_embed(self.ctx, "Leave guild", path="leave_guild")
 
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed, view=LeaveGuild(self.ctx))
 
-    @button(label="Go to path", style=ButtonStyle.blurple)
+    @button(label="Generate invite", style=ButtonStyle.blurple, row=1)
+    async def generate_invite_button(
+        self, button: Button, interaction: MessageInteraction
+    ):
+        """
+        buttons:
+            none
+        """
+
+        from .dialogs import Invite
+
+        embed = EmbedFactory.static_embed(self.ctx, "Generate invite", path="invite")
+
+        await interaction.response.defer()
+        await self.bot_message.edit(embed=embed, view=Invite(self.ctx))
+
+    @button(label="Go to", style=ButtonStyle.blurple, row=2)
     async def go_to_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
             none
         """
 
-        from .dialogs import (
-            Blacklist,
-            Change,
-            Eval,
-            Guild,
-            Invokes,
-            Manage,
-            ViewInfo
-        )
+        from .dialogs import Blacklist, Change, Eval, Guild, Invokes, Manage, ViewInfo
 
         paths = {
             "blacklist": Blacklist,
@@ -243,14 +253,14 @@ class DebugView(View):
             "invokes": Invokes,
             "leave_guild": Guild,
             "manage": Manage,
-            "view": ViewInfo
+            "view": ViewInfo,
         }
-
+        visual_paths = newline.join(["  -> /" + k for k in list(paths.keys())])
         embed = EmbedFactory.static_embed(
             self.ctx,
             "Go to path",
             path="go_to",
-            description="Type the path you want to go to (eg /blacklist/user)\nNot all paths are available because some require additional info (eg which guild to leave in leave_guild/leave)\n{paths}",
+            description=f"Type the path you want to go to eg /blacklist/user\nNot all paths are available because some require additional info\nPaths are:\n{visual_paths}",
         )
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message("What path?", ephemeral=True)
@@ -276,12 +286,13 @@ class DebugView(View):
                 self.ctx,
                 "Go to path",
                 path="go_to",
-                description=f"That is not a valid path\nPaths are:\n{newline.join(['     -> ' + k for k in list(paths.keys())])}",
+                description=f"That is not a valid path\nPaths are:\n{visual_paths}",
             )
             await self.bot_message.edit(embed=embed)
             await interaction.message.reply("Invalid path, try again")
+        return await interaction.message.reply("Cancelled the current `wait_for`")
 
-    @button(label="View", style=ButtonStyle.blurple)
+    @button(label="View", style=ButtonStyle.blurple, row=2)
     async def view_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
@@ -292,17 +303,16 @@ class DebugView(View):
             -> any
 
                 => show info
-        """ 
+        """
 
         from . import ViewInfo
 
-        embed = EmbedFactory.static_embed(
-            self.ctx, "View", path="view")
+        embed = EmbedFactory.static_embed(self.ctx, "View", path="view")
 
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed, view=ViewInfo(self.ctx))
 
-    @button(label="Stats", style=ButtonStyle.blurple)
+    @button(label="Stats", style=ButtonStyle.blurple, row=2)
     async def stats_button(self, button: Button, interaction: MessageInteraction):
 
         """
@@ -330,7 +340,7 @@ class DebugView(View):
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed)
 
-    @button(label="Help", style=ButtonStyle.blurple)
+    @button(label="Help", style=ButtonStyle.blurple, row=2)
     async def help_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
@@ -347,7 +357,7 @@ class DebugView(View):
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed)
 
-    @button(label="Manage bot", style=ButtonStyle.danger)
+    @button(label="Manage bot", style=ButtonStyle.danger, row=2)
     async def manage_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
