@@ -1,3 +1,4 @@
+from email.message import Message
 from ..utils import EmbedFactory, MainMenu, get_bot_message
 from fuzzywuzzy import fuzz
 from typing import List
@@ -10,7 +11,7 @@ from disnake.ext.commands import Bot, Context
 class Utilities:
     def __init__(self, ctx: Context) -> None:
         self.ctx = ctx
-        self.bot = ctx.bot
+        self.bot: Bot = ctx.bot
         self.bot_message = get_bot_message(ctx)
 
     async def other_guilds(self, interaction: MessageInteraction, clicked: str) -> None:
@@ -43,14 +44,16 @@ class Utilities:
                 item.disabled = True
         await self.bot_message.edit(embed=embed, view=self)
 
-        message = await self.bot.wait_for(
+        message: Message = await self.bot.wait_for(
             "message",
             check=lambda m: m.author == self.ctx.author
             and m.channel == self.ctx.channel,
         )
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         selected_guild = max(
-            [[guild, fuzz.ratio(message.content, guild.name)]
-             for guild in guilds],
+            [[guild, fuzz.ratio(message.content, guild.name)] for guild in guilds],
             key=lambda m: m[1],
         )
 
@@ -92,14 +95,16 @@ class Utilities:
         view.add_item(MainMenu(self.ctx))
         await self.bot_message.edit(embed=embed, view=view)
 
-        message = await self.bot.wait_for(
+        message: Message = await self.bot.wait_for(
             "message",
             check=lambda m: m.author == self.ctx.author
             and m.channel == self.ctx.channel,
         )
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         selected_guild = max(
-            [[guild, fuzz.ratio(message.content, guild.name)]
-             for guild in guilds],
+            [[guild, fuzz.ratio(message.content, guild.name)] for guild in guilds],
             key=lambda m: m[1],
         )[0]
 
@@ -161,7 +166,7 @@ class SelectPZ(Select):
     def __init__(self, ctx: Context):
         super().__init__()
 
-        self.bot = ctx.bot
+        self.bot: Bot = ctx.bot
         self.utils = Utilities(ctx)
         self.options = [
             SelectOption(label=str(k), value=str(k))
@@ -180,7 +185,7 @@ class SelectAO(Select):
     def __init__(self, ctx: Context):
         super().__init__()
 
-        self.bot = ctx.bot
+        self.bot: Bot = ctx.bot
         self.utils = Utilities(ctx)
         self.options = [
             SelectOption(label=str(k), value=str(k))
