@@ -5,9 +5,11 @@ from ..utils import EmbedFactory, MainMenu, get_bot_message
 
 from disnake import MessageInteraction, ButtonStyle
 from disnake.ui import View, Button, button
-from disnake.ext.commands import Context
+from disnake.ext.commands import Context, Bot
+
+newline = "\n"
+
 
-newline = '\n'
 class ConfirmShutdown(View):
     def __init__(self, ctx: Context, *, restart: bool = False):
         super().__init__()
@@ -22,14 +24,14 @@ class ConfirmShutdown(View):
             interaction.author == self.ctx.author
             and interaction.channel == self.ctx.channel
         )
-        
+
     async def restart_bot(self) -> None:
         """
         restart bot, if stuck in event loop stderr will never be created, hence triggering bot shut down
         """
 
         path = os.getcwd()
-        main = str(__main__.__file__).split('/')[-1]
+        main = str(__main__.__file__).split("/")[-1]
 
         proc = await asyncio.create_subprocess_shell(
             f"cd {path} && python {main}",
@@ -38,11 +40,13 @@ class ConfirmShutdown(View):
         )
         self.stdout, self.stderr = await proc.communicate()
         embed = EmbedFactory.static_embed(
-            self.ctx, "Uh oh!", path=f"manage/restart/error",
-            description=f"stderr: {self.stderr.decode()}\nstdout: {self.stdout.decode() if self.stdout else 'no stdout'}{newline + 'I am not shutting of the bot because I would error on startup' if self.stderr else ''}"
+            self.ctx,
+            "Uh oh!",
+            path=f"manage/restart/error",
+            description=f"stderr: {self.stderr.decode()}\nstdout: {self.stdout.decode() if self.stdout else 'no stdout'}{newline + 'I am not shutting of the bot because I would error on startup' if self.stderr else ''}",
         )
         await self.bot_message.edit(embed=embed)
-        
+
     @button(label="Yes", style=ButtonStyle.green)
     async def confirm_button(self, button: Button, interaction: MessageInteraction):
         """
@@ -52,24 +56,27 @@ class ConfirmShutdown(View):
         await interaction.response.defer()
         if not self.restart:
             embed = EmbedFactory.static_embed(
-                self.ctx, "Turned off bot", path=f"manage/shut_down",
-                description=f"The bot is now offline"
-            )   
+                self.ctx,
+                "Turned off bot",
+                path=f"manage/shut_down",
+                description=f"The bot is now offline",
+            )
             await self.bot_message.edit(embed=embed)
             return await self.ctx.bot.close()
-            
+
         asyncio.create_task(self.restart_bot())
         await asyncio.sleep(3)
         try:
             self.stderr
         except AttributeError:
             embed = EmbedFactory.static_embed(
-                self.ctx, "Turned off bot", path=f"manage/restart",
-                description=f"The bot is now offline"
-            )  
-            await self.bot_message.edit(embed=embed) 
+                self.ctx,
+                "Turned off bot",
+                path=f"manage/restart",
+                description=f"The bot is now offline",
+            )
+            await self.bot_message.edit(embed=embed)
             return await self.ctx.bot.close()
-        
 
     @button(label="No", style=ButtonStyle.danger)
     async def cancel_button(self, button: Button, interaction: MessageInteraction):
@@ -136,17 +143,23 @@ class Manage(View):
         """
 
         embed = EmbedFactory.static_embed(
-            self.ctx, "Are you sure you want to restart?", path="manage/restart",
-            description="WARNING: If there is an error on startup, the bot will not be able to start back up"
+            self.ctx,
+            "Are you sure you want to restart?",
+            path="manage/restart",
+            description="WARNING: If there is an error on startup, the bot will not be able to start back up",
         )
 
         await interaction.response.defer()
-        await self.bot_message.edit(embed=embed, view=ConfirmShutdown(self.ctx, restart=True))
+        await self.bot_message.edit(
+            embed=embed, view=ConfirmShutdown(self.ctx, restart=True)
+        )
 
     @button(label="Shut down", style=ButtonStyle.danger)
     async def shutdown_button(self, button: Button, interaction: MessageInteraction):
         embed = EmbedFactory.static_embed(
-            self.ctx, "Are you sure you want to shut the bot down?", path="manage/shut_down"
+            self.ctx,
+            "Are you sure you want to shut the bot down?",
+            path="manage/shut_down",
         )
 
         await interaction.response.defer()
